@@ -1,5 +1,5 @@
 totvar <- function(x, a = 0) {
-  y <- alfa(x, a, h = FALSE)$aff
+  y <- Compositional::alfa(x, a, h = FALSE)$aff
   s <- Rfast::colVars(y)
   sum(s)
 }
